# remirepo/Fedora spec file for php-zendframework-zend-xmlrpc
#
# Copyright (c) 2015-2020 Remi Collet
# License: CC-BY-SA
# http://creativecommons.org/licenses/by-sa/4.0/
#
# Please, preserve the changelog entries
#
%global bootstrap    0
%global gh_commit    9765e67d957d5c929d25e5870c51ad93ea806f49
%global gh_short     %(c=%{gh_commit}; echo ${c:0:7})
%global gh_owner     zendframework
%global gh_project   zend-xmlrpc
%global php_home     %{_datadir}/php
%global library      XmlRpc
%if %{bootstrap}
%global with_tests   0%{?_with_tests:1}
%else
%global with_tests   0%{!?_without_tests:1}
%endif

Name:           php-%{gh_owner}-%{gh_project}
Version:        2.9.0
Release:        1%{?dist}
Summary:        Zend Framework %{library} component

License:        BSD
URL:            https://zendframework.github.io/%{gh_project}/
Source0:        %{gh_commit}/%{name}-%{version}-%{gh_short}.tgz
Source1:        makesrc.sh

BuildArch:      noarch
# Tests
%if %{with_tests}
BuildRequires:  php(language) >= 5.6
BuildRequires:  php-simplexml
BuildRequires:  php-date
BuildRequires:  php-dom
BuildRequires:  php-iconv
BuildRequires:  php-libxml
BuildRequires:  php-pcre
BuildRequires:  php-spl
BuildRequires:  php-xmlwriter
# From composer, "require-dev": {
#        "phpunit/PHPUnit": "^5.7.27 || ^6.5.8 || ^7.1.2",
#        "zendframework/zend-coding-standard": "~1.0.0"
BuildRequires: (php-autoloader(%{gh_owner}/zend-http)           >= 2.5.4  with php-autoloader(%{gh_owner}/zend-http)           < 3)
BuildRequires: (php-autoloader(%{gh_owner}/zend-math)           >= 2.7    with php-autoloader(%{gh_owner}/zend-math)           < 4)
BuildRequires: (php-autoloader(%{gh_owner}/zend-server)         >= 2.7    with php-autoloader(%{gh_owner}/zend-server)         < 3)
BuildRequires: (php-autoloader(%{gh_owner}/zend-stdlib)         >= 3.2.1  with php-autoloader(%{gh_owner}/zend-stdlib)         < 4)
BuildRequires: (php-autoloader(%{gh_owner}/zendxml)             >= 1.0.2  with php-autoloader(%{gh_owner}/zendxml)             < 2)
%global phpunit %{_bindir}/phpunit7
BuildRequires:  phpunit7 >= 7.1.2
%endif
# Autoloader
BuildRequires:  php-fedora-autoloader-devel

# From composer, "require": {
#        "php": "^5.6 || ^7.0",
#        "zendframework/zend-http": "^2.5.4",
#        "zendframework/zend-math": "^2.7 || ^3.0",
#        "zendframework/zend-server": "^2.7",
#        "zendframework/zend-stdlib": "^3.2.1",
#        "zendframework/zendxml": "^1.0.2"
Requires:       php(language) >= 5.6
%if ! %{bootstrap}
Requires:      (php-autoloader(%{gh_owner}/zend-http)           >= 2.5.4  with php-autoloader(%{gh_owner}/zend-http)           < 3)
Requires:      (php-autoloader(%{gh_owner}/zend-math)           >= 2.7    with php-autoloader(%{gh_owner}/zend-math)           < 4)
Requires:      (php-autoloader(%{gh_owner}/zend-server)         >= 2.7    with php-autoloader(%{gh_owner}/zend-server)         < 3)
Requires:      (php-autoloader(%{gh_owner}/zend-stdlib)         >= 3.2.1  with php-autoloader(%{gh_owner}/zend-stdlib)         < 4)
Requires:      (php-autoloader(%{gh_owner}/zendxml)             >= 1.0.2  with php-autoloader(%{gh_owner}/zendxml)             < 2)
# From composer, "suggest": {
#        "zendframework/zend-cache": "To support Zend\\XmlRpc\\Server\\Cache usage"
Suggests:       php-autoloader(%{gh_owner}/zend-cache)
%endif
# Autoloader
Requires:       php-composer(fedora/autoloader)
# From phpcompatinfo report for version 2.5.2
Requires:       php-simplexml
Requires:       php-date
Requires:       php-dom
Requires:       php-iconv
Requires:       php-libxml
Requires:       php-pcre
Requires:       php-spl
Requires:       php-xmlwriter

Obsoletes:      php-ZendFramework2-%{library} < 2.5
Provides:       php-ZendFramework2-%{library} = %{version}
Provides:       php-composer(%{gh_owner}/%{gh_project}) = %{version}
Provides:       php-autoloader(%{gh_owner}/%{gh_project}) = %{version}


%description
From its home page, XML-RPC is described as a ”...remote procedure calling
using HTTP as the transport and XML as the encoding. XML-RPC is designed
to be as simple as possible, while allowing complex data structures to be
transmitted, processed and returned.”

Zend\XmlRpc provides support for both consuming remote XML-RPC services and
building new XML-RPC servers.

Documentation: https://zendframework.github.io/%{gh_project}/


%prep
%setup -q -n %{gh_project}-%{gh_commit}

mv LICENSE.md LICENSE


%build
: Generate autoloader
phpab --template fedora --output src/autoload.php src
cat << 'EOF' | tee -a src/autoload.php
\Fedora\Autoloader\Dependencies::required([
    '%{php_home}/Zend/Http/autoload.php',
    '%{php_home}/Zend/Math/autoload.php',
    '%{php_home}/Zend/Server/autoload.php',
    '%{php_home}/Zend/Stdlib/autoload.php',
    '%{php_home}/ZendXml/autoload.php',
]);
\Fedora\Autoloader\Dependencies::optional([
    '%{php_home}/Zend/Cache/autoload.php',
]);
EOF


%install
mkdir -p   %{buildroot}%{php_home}/Zend/
cp -pr src %{buildroot}%{php_home}/Zend/%{library}


%check
%if %{with_tests}
mkdir vendor
cat << 'EOF' | tee vendor/autoload.php
<?php
require_once '%{buildroot}%{php_home}/Zend/%{library}/autoload.php';
\Fedora\Autoloader\Autoload::addPsr4('ZendTest\\%{library}\\', dirname(__DIR__) . '/test');
require_once 'test/autoload.php';
require_once 'test/TestAsset/functions.php';
EOF

ret=0
for cmdarg in "php %{phpunit}" php71 php72 php73 php74; do
  if which $cmdarg; then
    set $cmdarg
    $1 ${2:-%{_bindir}/phpunit7} --verbose || ret=1
  fi
done
exit $ret
%else
: Test suite disabled
%endif


%files
%license LICENSE
%doc *.md
%doc composer.json
%{php_home}/Zend/%{library}


%changelog
* Fri Jan  3 2020 Remi Collet <remi@remirepo.net> - 2.9.0-1
- update to 2.9.0

* Mon Oct 21 2019 Remi Collet <remi@remirepo.net> - 2.8.0-1
- update to 2.8.0 (no change)
- raise dependency on zend-stdlib 3.2.1

* Fri Jul 26 2019 Fedora Release Engineering <releng@fedoraproject.org> - 2.7.0-5
- Rebuilt for https://fedoraproject.org/wiki/Fedora_31_Mass_Rebuild

* Sat Feb 02 2019 Fedora Release Engineering <releng@fedoraproject.org> - 2.7.0-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_30_Mass_Rebuild

* Fri Jul 13 2018 Fedora Release Engineering <releng@fedoraproject.org> - 2.7.0-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_29_Mass_Rebuild

* Tue May 15 2018 Remi Collet <remi@remirepo.net> - 2.7.0-1
- update to 2.7.0
- use range dependencies
- switch to phpunit7

* Fri Feb 09 2018 Fedora Release Engineering <releng@fedoraproject.org> - 2.6.2-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_28_Mass_Rebuild

* Fri Jan 26 2018 Remi Collet <remi@remirepo.net> - 2.6.2-1
- Update to 2.6.2
- switch to phpunit6

* Mon Dec 11 2017 Remi Collet <remi@remirepo.net> - 2.6.1-2
- switch from zend-loader to fedora/autoloader

* Fri Aug 11 2017 Remi Collet <remi@remirepo.net> - 2.6.1-1
- Update to 2.6.1

* Thu Jul 27 2017 Fedora Release Engineering <releng@fedoraproject.org> - 2.6.0-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_27_Mass_Rebuild

* Sat Feb 11 2017 Fedora Release Engineering <releng@fedoraproject.org> - 2.6.0-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_26_Mass_Rebuild

* Tue Jun 21 2016 Remi Collet <remi@fedoraproject.org> - 2.6.0-1
- update to 2.6.0
- raise dependency on PHP 5.6
- raise dependency on zend-server 2.7

* Fri Apr 22 2016 Remi Collet <remi@fedoraproject.org> - 2.5.2-1
- update to 2.5.2
- raise dependency on PHP >= 5.5
- raise dependency on zend-http >= 2.5.4
- raise dependency on zend-math >= 2.7
- raise dependency on zend-server >= 2.6.1
- raise dependency on zend-stdlib >= 2.7

* Thu Feb 04 2016 Fedora Release Engineering <releng@fedoraproject.org> - 2.5.1-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_24_Mass_Rebuild

* Tue Aug  4 2015 Remi Collet <remi@fedoraproject.org> - 2.5.1-1
- initial package
